@@ -27,7 +27,8 @@
 #include <inttypes.h>
 #include <string.h>
 
-#define FWTS_ACPI_BATTERY_HID "PNP0C0A"
+#define FWTS_ACPI_DEVICE_HID "PNP0C0A"
+#define FWTS_ACPI_DEVICE "battery"
 
 static ACPI_HANDLE device;
 
@@ -49,14 +50,14 @@ static int acpi_battery_init(fwts_framework *fw)
 	if (fwts_acpica_init(fw) != FWTS_OK)
 		return FWTS_ERROR;
 
-	status = AcpiGetDevices(FWTS_ACPI_BATTERY_HID, get_device_handle, NULL, NULL);
+	status = AcpiGetDevices(FWTS_ACPI_DEVICE_HID, get_device_handle, NULL, NULL);
 	if (ACPI_FAILURE(status)) {
 		fwts_log_error(fw, "Cannot find the ACPI device");
 		return FWTS_ERROR;
 	}
 
 	if (!device) {
-		fwts_log_error(fw, "ACPI Battery device does not exist, skipping test");
+		fwts_log_error(fw, "ACPI %s device does not exist, skipping test", FWTS_ACPI_DEVICE);
 		fwts_acpica_deinit();
 		return FWTS_SKIP;
 	} else {
@@ -68,7 +69,7 @@ static int acpi_battery_init(fwts_framework *fw)
 
 		status = AcpiGetName(device, ACPI_FULL_PATHNAME, &buffer);
 		if (ACPI_SUCCESS(status)) {
-			fwts_log_info_verbatim(fw, "ACPI Battery Device: %s", full_name);
+			fwts_log_info_verbatim(fw, "ACPI %s device: %s", FWTS_ACPI_DEVICE, full_name);
 			fwts_log_nl(fw);
 		}
 	}
@@ -449,7 +450,7 @@ static int method_test_BMA(fwts_framework *fw)
 	arg[0].Integer.Value = 1;
 
 	return fwts_evaluate_method(fw, METHOD_OPTIONAL, &device,
-		"_BMA", arg, 1, fwts_method_test_integer_return, NULL);
+		"_BMA", arg, 1, fwts_method_test_passed_failed_return, "_BMA");
 }
 
 static int method_test_BMS(fwts_framework *fw)
@@ -459,7 +460,7 @@ static int method_test_BMS(fwts_framework *fw)
 	arg[0].Integer.Value = 1;
 
 	return fwts_evaluate_method(fw, METHOD_OPTIONAL, &device,
-		"_BMS", arg, 1, fwts_method_test_integer_return, NULL);
+		"_BMS", arg, 1, fwts_method_test_passed_failed_return, "_BMS");
 }
 
 static void method_test_BST_return(
@@ -545,7 +546,7 @@ static int method_test_BTP(fwts_framework *fw)
 	ACPI_STATUS status;
 	uint8_t i;
 
-	for (i = 0; i < sizeof(values) / sizeof(int); i++) {
+	for (i = 0; i < FWTS_ARRAY_SIZE(values); i++) {
 		ACPI_OBJECT arg[1];
 		arg[0].Type = ACPI_TYPE_INTEGER;
 		arg[0].Integer.Value = values[i];
@@ -626,7 +627,7 @@ static int method_test_BTM(fwts_framework *fw)
 	ACPI_STATUS status;
 	uint8_t i;
 
-	for (i = 0; i < sizeof(values) / sizeof(int); i++) {
+	for (i = 0; i < FWTS_ARRAY_SIZE(values); i++) {
 		ACPI_OBJECT arg[1];
 		arg[0].Type = ACPI_TYPE_INTEGER;
 		arg[0].Integer.Value = values[i];
@@ -653,31 +654,10 @@ static int method_test_BCT(fwts_framework *fw)
 		"_BCT", arg, 1, fwts_method_test_integer_return, NULL);
 }
 
-static void method_test_BMD_return(
-	fwts_framework *fw,
-	char *name,
-	ACPI_BUFFER *buf,
-	ACPI_OBJECT *obj,
-	void *private)
-{
-	FWTS_UNUSED(private);
-
-	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
-		return;
-
-	if (fwts_method_package_count_equal(fw, name, "_BMD", obj, 5) != FWTS_OK)
-		return;
-
-	if (fwts_method_package_elements_all_type(fw, name, "_BMD", obj, ACPI_TYPE_INTEGER) != FWTS_OK)
-		return;
-
-	fwts_method_passed_sane(fw, name, "package");
-}
-
 static int method_test_BMD(fwts_framework *fw)
 {
 	return fwts_evaluate_method(fw, METHOD_OPTIONAL, &device,
-		"_BMD", NULL, 0, method_test_BMD_return, NULL);
+		"_BMD", NULL, 0, fwts_method_test_BMD_return, NULL);
 }
 
 static int method_test_BMC(fwts_framework *fw)
@@ -686,7 +666,7 @@ static int method_test_BMC(fwts_framework *fw)
 	ACPI_STATUS status;
 	uint8_t i;
 
-	for (i = 0; i < sizeof(values) / sizeof(int); i++) {
+	for (i = 0; i < FWTS_ARRAY_SIZE(values); i++) {
 		ACPI_OBJECT arg[1];
 		arg[0].Type = ACPI_TYPE_INTEGER;
 		arg[0].Integer.Value = values[i];
@@ -698,7 +678,7 @@ static int method_test_BMC(fwts_framework *fw)
 	return FWTS_OK;
 }
 
-/* EvaluateD evice Identification Objects - all are optional */
+/* Evaluate Device Identification Objects - all are optional */
 static int method_test_ADR(fwts_framework *fw)
 {
 	return fwts_method_test_ADR(fw, &device);
