@@ -27,7 +27,8 @@
 #include <inttypes.h>
 #include <string.h>
 
-#define FWTS_ACPI_TIME_ALARM_HID "ACPI000E"
+#define FWTS_ACPI_DEVICE_HID "ACPI000E"
+#define FWTS_ACPI_DEVICE "time and alarm"
 
 static ACPI_HANDLE device;
 
@@ -51,14 +52,14 @@ static int acpi_time_alarm_init(fwts_framework *fw)
 	if (fwts_acpica_init(fw) != FWTS_OK)
 		return FWTS_ERROR;
 
-	status = AcpiGetDevices(FWTS_ACPI_TIME_ALARM_HID, get_device_handle, NULL, NULL);
+	status = AcpiGetDevices(FWTS_ACPI_DEVICE_HID, get_device_handle, NULL, NULL);
 	if (ACPI_FAILURE(status)) {
 		fwts_log_error(fw, "Cannot find the ACPI device");
 		return FWTS_ERROR;
 	}
 
 	if (!device) {
-		fwts_log_error(fw, "ACPI time and alarm device does not exist, skipping test");
+		fwts_log_error(fw, "ACPI %s device does not exist, skipping test", FWTS_ACPI_DEVICE);
 		fwts_acpica_deinit();
 		return FWTS_SKIP;
 	} else {
@@ -70,7 +71,7 @@ static int acpi_time_alarm_init(fwts_framework *fw)
 
 		status = AcpiGetName(device, ACPI_FULL_PATHNAME, &buffer);
 		if (ACPI_SUCCESS(status)) {
-			fwts_log_info_verbatim(fw, "ACPI Time and Alarm Device: %s", full_name);
+			fwts_log_info_verbatim(fw, "ACPI %s device: %s", FWTS_ACPI_DEVICE, full_name);
 			fwts_log_nl(fw);
 		}
 	}
@@ -121,14 +122,8 @@ static void method_test_GRT_return(
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
 		return;
 
-	if (obj->Buffer.Length != 16) {
-		fwts_failed(fw, LOG_LEVEL_CRITICAL,
-			"Method_GRTBadBufferSize",
-			"%s should return a buffer of 16 bytes, but "
-			"instead just returned %" PRIu32,
-			name, obj->Buffer.Length);
+	if (fwts_method_buffer_size(fw, name, obj, 16) != FWTS_OK)
 		return;
-	}
 
 	/*
 	 * Should sanity check this, but we can't read the
@@ -270,7 +265,7 @@ static int method_test_STP(fwts_framework *fw)
 	arg[1].Integer.Value = 0;	/* wake up instantly */
 
 	return fwts_evaluate_method(fw, METHOD_OPTIONAL, &device,
-		"_STP", arg, 2, fwts_method_test_passed_failed_return, NULL);
+		"_STP", arg, 2, fwts_method_test_passed_failed_return, "_STP");
 }
 
 static int method_test_STV(fwts_framework *fw)
@@ -283,7 +278,7 @@ static int method_test_STV(fwts_framework *fw)
 	arg[1].Integer.Value = 100;	/* timer value */
 
 	return fwts_evaluate_method(fw, METHOD_MANDATORY, &device,
-		"_STV", arg, 2, fwts_method_test_passed_failed_return, NULL);
+		"_STV", arg, 2, fwts_method_test_passed_failed_return, "_STV");
 }
 
 static int method_test_TIP(fwts_framework *fw)
@@ -308,7 +303,7 @@ static int method_test_TIV(fwts_framework *fw)
 		"_TIV", arg, 1, fwts_method_test_integer_return, NULL);
 }
 
-/* EvaluateD evice Identification Objects - all are optional */
+/* Evaluate Device Identification Objects - all are optional */
 static int method_test_ADR(fwts_framework *fw)
 {
 	return fwts_method_test_ADR(fw, &device);
