@@ -35,7 +35,7 @@
 #include <limits.h>
 #include <fcntl.h>
 
-#define DMI_VERSION			(0x0320)
+#define DMI_VERSION			(0x0330)
 #define VERSION_MAJOR(v)		((v) >> 8)
 #define VERSION_MINOR(v)		((v) & 0xff)
 
@@ -90,6 +90,11 @@ typedef struct {
 	uint8_t length;
 } fwts_dmi_type_length;
 
+typedef struct {
+	uint16_t min;
+	uint16_t max;
+} fwts_dmi_value_range;
+
 static bool smbios_found = false;
 static bool smbios30_found = false;
 
@@ -236,6 +241,8 @@ static const fwts_dmi_used_by_kernel dmi_used_by_kernel_table[] = {
 	{ 0, 4 },
 	{ 0, 5 },
 	{ 0, 8 },
+	{ 0, 21 },
+	{ 0, 23 },
 	/* Type 1, System Information */
 	{ 1, 4 },
 	{ 1, 5 },
@@ -282,6 +289,8 @@ static const fwts_dmi_type_length type_info[] = {
 	{ 17, 0x207, 0x206, 0x1c },
 	{ 17, 0x208, 0x207, 0x22 },
 	{ 17, 0x302, 0x208, 0x28 },
+	{ 17, 0x303, 0x302, 0x54 },
+	{ 17, MAX_VERSION, 0x303, 0x5c },
 	{ 19, 0x207, 0x201, 0xf },
 	{ 19, MAX_VERSION, 0x207, 0x1f },
 	{ 20, 0x207, 0x201, 0x13 },
@@ -906,6 +915,32 @@ static void dmi_reserved_uint8_check(fwts_framework *fw,
 	}
 }
 
+static void dmi_ranges_uint8_check(fwts_framework *fw,
+	const char *table,
+	uint32_t addr,
+	const char *field,
+	const fwts_dmi_header *hdr,
+	uint8_t offset,
+	fwts_dmi_value_range* ranges,
+	uint32_t range_size)
+{
+	uint16_t i;
+	uint8_t val = hdr->data[offset];
+
+	for (i = 0; i < range_size / sizeof(fwts_dmi_value_range); i++) {
+		fwts_dmi_value_range *range = ranges + i;
+		if ((val >= range->min) && (val <= range->max))
+			return;
+	}
+
+	fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
+		"Out of range value 0x%2.2" PRIx8 " "
+		"while accessing entry '%s' @ 0x%8.8" PRIx32
+		", field '%s', offset 0x%2.2" PRIx8,
+		val, table, addr, field, offset);
+		dmi_out_of_range_advice(fw, hdr->type, offset);
+}
+
 static void dmi_min_max_uint32_check(fwts_framework *fw,
 	const char *table,
 	uint32_t addr,
@@ -1260,6 +1295,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Asset Tag", hdr, 0x8);
 			if (hdr->length < 0x0f)
 				break;
+			dmi_reserved_bits_check(fw, table, addr, "Feature Flags", hdr, sizeof(uint8_t), 0x9, 5, 7);
 			dmi_str_check(fw, table, addr, "Location In Chassis", hdr, 0xa);
 			dmi_min_max_uint8_check(fw, table, addr, "Type", hdr, 0xd, 0x1, 0xd);
 			break;
@@ -1269,16 +1305,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x09)
 				break;
 			dmi_str_check(fw, table, addr, "Manufacturer", hdr, 0x4);
-			dmi_min_max_mask_uint8_check(fw, table, addr, "Chassis Type", hdr, 0x5, 0x1, 0x24, 0x0, 0x7f);
-
-			if ((data[5] & ~0x80) >= FWTS_SMBIOS_CHASSIS_MAX) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_INVALID_HARDWARE_ENTRY,
-					"Incorrect Chassis Type "
-					"SMBIOS Type 3 reports 0x%" PRIx8,
-					(data[5] & ~0x80));
-				break;
-			}
-
+			dmi_min_max_mask_uint8_check(fw, table, addr, "Chassis Type", hdr, 0x5, 0x1, FWTS_SMBIOS_CHASSIS_MAX - 1, 0x0, 0x7f);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Chassis Lock", hdr, 0x5, 0x0, 0x1, 0x7, 0x1);
 			dmi_str_check(fw, table, addr, "Version", hdr, 0x6);
 			dmi_str_check(fw, table, addr, "Serial Number", hdr, 0x7);
@@ -1338,7 +1365,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Part Number", hdr, 0x22);
 			if (hdr->length < 0x28)
 				break;
-			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 8, 15);
+			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 9, 15);
 			if (hdr->length < 0x30)
 				break;
 			dmi_min_max_uint16_check(fw, table, addr, "Core Count 2", hdr, 0x2a, 0, 0xfffe);
@@ -1377,6 +1404,7 @@ static void dmicheck_entry(fwts_framework *fw,
 					table, addr, "Cache Location", 0x5);
 
 			dmi_reserved_bits_check(fw, table, addr, "Cache Location", hdr, sizeof(uint16_t), 0x05, 10, 15);
+			dmi_reserved_bits_check(fw, table, addr, "Supported SRAM Type", hdr, sizeof(uint16_t), 0x0b, 7, 15);
 			dmi_reserved_bits_check(fw, table, addr, "Current SRAM Type", hdr, sizeof(uint16_t), 0x0d, 7, 15);
 			if (hdr->length < 0x13)
 				break;
@@ -1390,35 +1418,12 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x09)
 				break;
 			dmi_str_check(fw, table, addr, "Internal Reference Designator", hdr, 0x4);
-			if (!((data[0x5] <= 0x23) ||
-			      (data[0x5] == 0xff) ||
-			      ((data[0x5] >= 0xa0) && (data[0x5] <= 0xa4))))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x23, 0xa0..0xa4, 0xff) "
-					"while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					data[0x5], table, addr, "Internal Connector Type", 0x5);
+			fwts_dmi_value_range t8_ranges1[] = {{0, 0x23}, {0xa0, 0xa4}, {0xff, 0xff}};
+			dmi_ranges_uint8_check(fw, table, addr, "Internal Connector Type", hdr, 0x5, t8_ranges1, sizeof(t8_ranges1));
 			dmi_str_check(fw, table, addr, "External Reference Designator", hdr, 0x6);
-			if (!((data[0x7] <= 0x23) ||
-			      (data[0x7] == 0xff) ||
-			      ((data[0x7] >= 0xa0) && (data[0x7] <= 0xa4))))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x23, 0xa0..0xa4, 0xff) "
-					"while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					data[0x7], table, addr, "Internal Connector Type", 0x7);
-
-			if (!((data[0x8] <= 0x23) ||
-			      (data[0x8] == 0xff) ||
-			      ((data[0x8] >= 0xa0) && (data[0x8] <= 0xa1))))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x23, 0xa0..0xa1, 0xff) "
-					"while accessing entry '%s' @ 0x%8.8" PRIx32 ", "
-					"field '%s', offset 0x%2.2x",
-					data[0x8], table, addr, "Port Type", 0x8);
+			dmi_ranges_uint8_check(fw, table, addr, "External Connector Type", hdr, 0x7, t8_ranges1, sizeof(t8_ranges1));
+			fwts_dmi_value_range t8_ranges2[] = {{0, 0x23}, {0xa0, 0xa1}, {0xff, 0xff}};
+			dmi_ranges_uint8_check(fw, table, addr, "Port Type", hdr, 0x8, t8_ranges2, sizeof(t8_ranges2));
 			break;
 
 		case 9: /* 7.10 */
@@ -1426,14 +1431,8 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x0c)
 				break;
 			dmi_str_check(fw, table, addr, "Slot Designation", hdr, 0x4);
-			if (!(((data[0x5] >= 0x01) && (data[0x5] <= 0x23)) ||
-			      ((data[0x5] >= 0xa0) && (data[0x5] <= 0xb6))))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x01..0x23, 0xa0..0xb6) "
-					"while accessing entry '%s' @ 0x%8.8" PRIx32 ", "
-					"field '%s', offset 0x%2.2x",
-					data[0x5], table, addr, "Slot Type", 0x5);
+			fwts_dmi_value_range t9_ranges[] = {{1, 0x23}, {0x30, 0x30}, {0xa0, 0xbd}};
+			dmi_ranges_uint8_check(fw, table, addr, "Slot Type", hdr, 0x5, t9_ranges, sizeof(t9_ranges));
 			dmi_min_max_uint8_check(fw, table, addr, "Slot Data Bus Width", hdr, 0x6, 0x1, 0xe);
 			dmi_min_max_uint8_check(fw, table, addr, "Current Usage", hdr, 0x7, 0x1, 0x5);
 			dmi_min_max_uint8_check(fw, table, addr, "Slot Length", hdr, 0x8, 0x1, 0x6);
@@ -1507,7 +1506,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_reserved_bits_check(fw, table, addr, "Flags", hdr, sizeof(uint8_t), 0x5, 1, 7);
 			if (hdr->length < 0x15)
 				break;
-			for (i = 0x6; i < 0x15; i++)
+			for (i = 0x6; i < 15; i++)
 				dmi_reserved_uint8_check(fw, table, addr, "Reserved", hdr, i);
 			if (hdr->length < 0x16)
 				break;
@@ -1529,27 +1528,13 @@ static void dmicheck_entry(fwts_framework *fw,
 			table = "System Event Log (Type 15)";
 			if (hdr->length < 0x14)
 				break;
-			val = hdr->data[0x0a];
-			if (!((val <= 0x04) || (val >= 0x80))) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x04, "
-					"0x80..0xff) while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					val, table, addr, "Access Method", 0x0a);
-			}
+			fwts_dmi_value_range t15_ranges1[] = {{0, 0x4}, {0x80, 0xff}};
+			dmi_ranges_uint8_check(fw, table, addr, "Access Method", hdr, 0xa, t15_ranges1, sizeof(t15_ranges1));
 			dmi_reserved_bits_check(fw, table, addr, "Log Status", hdr, sizeof(uint8_t), 0xb, 2, 7);
 			if (hdr->length < 0x17)
 				break;
-			val = hdr->data[0x14];
-			if (!((val <= 0x01) || (val >= 0x80))) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x01, "
-					"0x80..0xff) while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					val, table, addr, "Log Header Format", 0x14);
-			}
+			fwts_dmi_value_range t15_ranges2[] = {{0, 0x1}, {0x80, 0xff}};
+			dmi_ranges_uint8_check(fw, table, addr, "Log Header Format", hdr, 0x14, t15_ranges2, sizeof(t15_ranges2));
 			if (hdr->length < 0x17 + data[0x15] * data[0x16])
 				break;
 			if (data[0x16] >= 0x02) {
@@ -1585,14 +1570,8 @@ static void dmicheck_entry(fwts_framework *fw,
 			table = "Physical Memory Array (Type 16)";
 			if (hdr->length < 0x0f)
 				break;
-			if (!(((data[0x4] >= 0x01) && (data[0x4] <= 0x0a)) ||
-			      ((data[0x4] >= 0xa0) && (data[0x4] <= 0xa3))))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x01..0x0a, 0xa0..0xa3) "
-					"while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					data[0x4], table, addr, "Location", 0x4);
+			fwts_dmi_value_range t16_ranges[] = {{0x1, 0xa}, {0xa0, 0xa4}};
+			dmi_ranges_uint8_check(fw, table, addr, "Location", hdr, 0x4, t16_ranges, sizeof(t16_ranges));
 			dmi_min_max_uint8_check(fw, table, addr, "Use", hdr, 0x5, 0x1, 0x7);
 			dmi_min_max_uint8_check(fw, table, addr, "Error Corrrection Type", hdr, 0x6, 0x1, 0x7);
 			dmi_min_max_uint32_check(fw, table, addr, "Maximum Capacity", hdr, 0x7, 0, 0x80000000);
@@ -1612,10 +1591,10 @@ static void dmicheck_entry(fwts_framework *fw,
 				break;
 			if (hdr->length < 0x15)
 				break;
-			dmi_min_max_uint8_check(fw, table, addr, "Form Factor", hdr, 0xe, 0x1, 0xf);
+			dmi_min_max_uint8_check(fw, table, addr, "Form Factor", hdr, 0xe, 0x1, 0x10);
 			dmi_str_check(fw, table, addr, "Locator", hdr, 0x10);
 			dmi_str_check(fw, table, addr, "Bank Locator", hdr, 0x11);
-			dmi_min_max_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, 0x1, 0x1f);
+			dmi_min_max_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, 0x1, 0x21);
 			if (hdr->length < 0x1b)
 				break;
 			dmi_str_check(fw, table, addr, "Manufacturer", hdr, 0x17);
@@ -1628,10 +1607,15 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x20)
 				break;
 			dmi_reserved_bits_check(fw, table, addr, "Extended Size", hdr, sizeof(uint32_t), 0x1c, 31, 31);
-			if (hdr->length < 0x3c)
+			if (hdr->length < 0x4c)
 				break;
 			dmi_min_max_uint8_check(fw, table, addr, "Memory Technology", hdr, 0x28, 0x1, 0x7);
 			dmi_reserved_bits_check(fw, table, addr, "Memory Operating Mode Cap", hdr, sizeof(uint16_t), 0x29, 6, 15);
+			dmi_str_check(fw, table, addr, "Firmware Version", hdr, 0x2b);
+			if (hdr->length < 0x54)
+				break;
+			dmi_reserved_bits_check(fw, table, addr, "Extended Speed", hdr, sizeof(uint32_t), 0x54, 31, 31);
+			dmi_reserved_bits_check(fw, table, addr, "Extended Configured Memory Speed", hdr, sizeof(uint32_t), 0x58, 31, 31);
 
 			break;
 
@@ -1699,14 +1683,8 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x07)
 				break;
 			dmi_min_max_uint8_check(fw, table, addr, "Type", hdr, 0x4, 0x1, 0x9);
-			if (!(((data[0x5] >= 0x01) && (data[0x5] <= 0x08)) ||
-			      ((data[0x5] >= 0xa0) && (data[0x5] <= 0xa2)))) {
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x01..0x08, 0xa0..0xa2) "
-					"while accessing '%s', field '%s', offset 0x%2.2x",
-					data[0x5], table, "Interface", 0x5);
-			}
+			fwts_dmi_value_range t21_ranges[] = {{0x1, 0x8}, {0xa0, 0xa2}};
+			dmi_ranges_uint8_check(fw, table, addr, "Interface", hdr, 0x5, t21_ranges, sizeof(t21_ranges));
 			break;
 
 		case 22: /* 7.23 */
@@ -1768,6 +1746,13 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Description", hdr, 0x4);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Location (bits 0..4)", hdr, 0x5, 0x1, 0xb, 0, 0x1f);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Status (bits 5..7)", hdr, 0x5, 0x1, 0x6, 5, 0x7);
+			dmi_min_max_uint16_check(fw, table, addr, "Maximum Value", hdr, 0x6, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Minimum Value", hdr, 0x8, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Resolution", hdr, 0xa, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Tolerance", hdr, 0xc, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Accuracy", hdr, 0xe, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Nominal Value", hdr, 0x14, 0, 0x8000);
+
 			break;
 
 		case 27: /* 7.28 */
@@ -1787,6 +1772,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Status (bits 5..7)", hdr, 0x6, 0x1, 0x6, 5, 0x7);
 			if (hdr->length < 0x0f)
 				break;
+			dmi_min_max_uint16_check(fw, table, addr, "Nominal Speed", hdr, 0xc, 0, 0x8000);
 			dmi_str_check(fw, table, addr, "Description", hdr, 0xe);
 			break;
 
@@ -1797,6 +1783,12 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Description", hdr, 0x4);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Location (bits 0..4)", hdr, 0x5, 0x1, 0xf, 0, 0x1f);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Status (bits 5..7)", hdr, 0x5, 0x1, 0x6, 5, 0x7);
+			dmi_min_max_uint16_check(fw, table, addr, "Maximum Value", hdr, 0x6, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Minimum Value", hdr, 0x8, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Resolution", hdr, 0xa, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Tolerance", hdr, 0xc, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Accuracy", hdr, 0xe, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Nominal Value", hdr, 0x14, 0, 0x8000);
 			break;
 
 		case 29: /* 7.30 */
@@ -1806,6 +1798,12 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Description", hdr, 0x4);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Location (bits 0..4)", hdr, 0x5, 0x1, 0xb, 0, 0x1f);
 			dmi_min_max_mask_uint8_check(fw, table, addr, "Status (bits 5..7)", hdr, 0x5, 0x1, 0x6, 5, 0x7);
+			dmi_min_max_uint16_check(fw, table, addr, "Maximum Value", hdr, 0x6, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Minimum Value", hdr, 0x8, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Resolution", hdr, 0xa, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Tolerance", hdr, 0xc, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Accuracy", hdr, 0xe, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Nominal Value", hdr, 0x14, 0, 0x8000);
 			break;
 
 		case 30: /* 7.31 */
@@ -1830,13 +1828,8 @@ static void dmicheck_entry(fwts_framework *fw,
 				break;
 			for (i = 4; i <= 9; i++)
 				dmi_reserved_uint8_check(fw, table, addr, "Reserved", hdr, i);
-			if ((data[0xa] > 0x8) && (data[0xa] < 128))
-				fwts_failed(fw, LOG_LEVEL_HIGH, DMI_VALUE_OUT_OF_RANGE,
-					"Out of range value 0x%2.2" PRIx8 " "
-					"(range allowed 0x00..0x08, 0x80..0xff) "
-					"while accessing entry '%s' @ "
-					"0x%8.8" PRIx32 ", field '%s', offset 0x%2.2x",
-					data[0xa], table, addr, "Boot Status", 0xa);
+			fwts_dmi_value_range t32_ranges[] = {{0, 0x8}, {0x80, 0xff}};
+			dmi_ranges_uint8_check(fw, table, addr, "Boot Status", hdr, 0xa, t32_ranges, sizeof(t32_ranges));
 			break;
 
 		case 33: /* 7.34 */
@@ -1866,10 +1859,14 @@ static void dmicheck_entry(fwts_framework *fw,
 
 		case 36: /* 7.37 */
 			table = "Management Device Threshold Data (Type 36)";
-			/*
 			if (hdr->length < 0x10)
 				break;
-			*/
+			dmi_min_max_uint16_check(fw, table, addr, "Lower Threshold - Non-critical", hdr, 0x4, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Upper Threshold - Non-critical", hdr, 0x6, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Lower Threshold - Critical", hdr, 0x8, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Upper Threshold - Critical", hdr, 0xa, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Lower Threshold - Non-recoverable", hdr, 0xc, 0, 0x8000);
+			dmi_min_max_uint16_check(fw, table, addr, "Upper Threshold - Non-recoverable", hdr, 0xe, 0, 0x8000);
 			break;
 
 		case 37: /* 7.38 */
@@ -1901,6 +1898,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Asset Tag", hdr, 0x9);
 			dmi_str_check(fw, table, addr, "Model Part Number", hdr, 0xa);
 			dmi_str_check(fw, table, addr, "Revision Level", hdr, 0xb);
+			dmi_min_max_uint16_check(fw, table, addr, "Max Power Capacity", hdr, 0xc, 0, 0x8000);
 			dmi_reserved_bits_check(fw, table, addr, "Power Supply Characteristics", hdr, sizeof(uint16_t), 0xe, 14, 15);
 			break;
 
@@ -1936,13 +1934,20 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x1b)
 				break;
 			dmi_str_check(fw, table, addr, "Description", hdr, 0x12);
+			dmi_reserved_bits_check(fw, table, addr, "Characteristics", hdr, sizeof(uint64_t), 0x13, 0, 1);
 			dmi_reserved_bits_check(fw, table, addr, "Characteristics", hdr, sizeof(uint64_t), 0x13, 6, 63);
 			break;
 
-		case 126: /* 7.45 */
+		case 44: /* 7.45 */
+			table = "Processor Additional Information (Type 44)";
+			if (hdr->length < 0x6)
+				break;
+			break;
+
+		case 126: /* 7.46 */
 			table = "Inactive (Type 126)";
 			break;
-		case SMBIOS_END_OF_TABLE: /* 7.46 */
+		case SMBIOS_END_OF_TABLE: /* 7.47 */
 			table = "End of Table (Type 127)";
 			break;
 		default:
