@@ -118,6 +118,13 @@
 #define FWTS_USE_DEVMEM 1
 #endif
 
+#if defined(__riscv)
+#define FWTS_ARCH_RISCV	1
+#define FWTS_HAS_ACPI	1
+#define FWTS_HAS_UEFI	1
+#define FWTS_USE_DEVMEM 1
+#endif
+
 /* verision 3-tuple into integer */
 #define _VER_(major, minor, patchlevel)                 \
 	((major * 10000) + (minor * 100) + patchlevel)
@@ -146,6 +153,8 @@
 
 #define FWTS_JSON_DATA_PATH	DATAROOTDIR "/fwts"
 
+#include <inttypes.h>
+
 #include "fwts_version.h"
 #include "fwts_backtrace.h"
 #include "fwts_types.h"
