@@ -32,7 +32,7 @@ typedef enum {
 
 extern fwts_architecture fwts_arch_get_host(void);
 extern fwts_architecture fwts_arch_get_arch(const char *name);
-extern const char *fwts_arch_names(void);
+extern char *fwts_arch_names(void);
 extern const char *fwts_arch_get_name(const fwts_architecture arch);
 
 #endif
