@@ -63,7 +63,9 @@ typedef enum {
 	FWTS_FLAG_TEST_COMPLIANCE_ACPI		= 0x00800000,
 	FWTS_FLAG_TEST_SBBR			= 0x01000000,
 	FWTS_FLAG_TEST_EBBR			= 0x02000000,
-	FWTS_FLAG_TEST_XBBR			= FWTS_FLAG_TEST_SBBR | FWTS_FLAG_TEST_EBBR
+	FWTS_FLAG_TEST_XBBR			= FWTS_FLAG_TEST_SBBR | FWTS_FLAG_TEST_EBBR,
+	FWTS_FLAG_DUMP_ACPI_FROM_SYSFS		= 0x08000000,
+
 } fwts_framework_flags;
 
 #define FWTS_FLAG_TEST_MASK		\
