@@ -575,7 +575,28 @@ bool fwts_method_type_matches(ACPI_OBJECT_TYPE t1, ACPI_OBJECT_TYPE t2)
 }
 
 /*
- *  method_package_count_min()
+ *  fwts_method_buffer_size()
+ *	check whether buffer size is matched
+ */
+int fwts_method_buffer_size(
+	fwts_framework *fw,
+	const char *name,
+	ACPI_OBJECT *obj,
+	size_t buf_size)
+{
+	if (obj->Buffer.Length != buf_size) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"MethodBadBufferSize",
+			"%s should return a buffer of %zd bytes, "
+			"but instead returned %" PRIu32 " bytes.",
+			name, buf_size, obj->Buffer.Length);
+		return FWTS_ERROR;
+	}
+	return FWTS_OK;
+}
+
+/*
+ *  fwts_method_package_count_min()
  *	check that an ACPI package has at least 'min' elements
  */
 int fwts_method_package_count_min(
@@ -801,6 +822,118 @@ void fwts_method_test_buffer_return(
 			name, obj->Buffer.Length);
 }
 
+/*
+ *  fwts_method_test_all_reference_package_return
+ *	check if all elements are references in a package
+ */
+void fwts_method_test_all_reference_package_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	char *objname = (char *)private;
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_all_type(fw, name, objname, obj, ACPI_TYPE_LOCAL_REFERENCE) != FWTS_OK)
+		return;
+
+	fwts_passed(fw,	"%s returned a sane package of %" PRIu32 " references.", name, obj->Package.Count);
+}
+
+/*
+ *  fwts_method_test_integer_reserved_bits_return
+ *	check if reserved bits are zero'ed in a returned integer
+ */
+void fwts_method_test_integer_reserved_bits_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	uint64_t *mask = (uint64_t *) private;
+	bool failed = false;
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_INTEGER) != FWTS_OK)
+		return;
+
+	if (obj->Integer.Value & *mask) {
+		failed = true;
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MethodIllegalReserved",
+			"%s returned value 0x%8.8" PRIx64 " and some of the "
+			"reserved bits are set when they should be zero.",
+			name, (uint64_t) obj->Integer.Value);
+	}
+
+	if (!failed)
+		fwts_passed(fw, "%s correctly returned an integer.", name);
+}
+
+/*
+ *  fwts_method_test_integer_max_return
+ *	check if returned integer is less than a max value
+ */
+void fwts_method_test_integer_max_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	uint64_t *max = (uint64_t *) private;
+	bool failed = false;
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_INTEGER) != FWTS_OK)
+		return;
+
+	if (obj->Integer.Value > *max) {
+		failed = true;
+		fwts_failed(fw, LOG_LEVEL_HIGH, "MethodOutOfRangeValue",
+			"%s returned value %" PRId64 " but range allowed "
+			"is 0..%" PRId64 " .",
+			name, (uint64_t) obj->Integer.Value, *max);
+	}
+
+	if (!failed)
+		fwts_passed(fw, "%s correctly returned an integer.", name);
+}
+
+/*
+ *  fwts_method_test_package_integer_return
+ *	check if all integers in a returned package
+ */
+void fwts_method_test_package_integer_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	char method[5];
+	uint32_t *element_size = (uint32_t *) private;
+
+	if (strlen(name) < 4)
+		return;
+
+	memcpy(method, name + strlen(name) - 4, 4);
+	method[4] = '\0';
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_count_equal(fw, name, method, obj, *element_size) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_all_type(fw, name, method, obj, ACPI_TYPE_INTEGER) != FWTS_OK)
+		return;
+
+	fwts_method_passed_sane(fw, name, "package");
+}
+
 /*
  *  fwts_method_test_passed_failed_return
  *	check if 0 or 1 (false/true) integer is returned
@@ -820,11 +953,11 @@ void fwts_method_test_passed_failed_return(
 		else {
 			fwts_failed(fw, LOG_LEVEL_CRITICAL,
 				"MethodReturnZeroOrOne",
-				"%s returned 0x%8.8" PRIx32 ", should return 1 "
-				"(success) or 0 (failed).", method, val);
+				"%s returned 0x%8.8" PRIx32 ", should return 0 "
+				"or 1.", method, val);
 			fwts_advice(fw,
 				"Method %s should be returning the correct "
-				"1/0 success/failed return values. "
+				"0 or 1 return values. "
 				"Unexpected behaviour may occur becauses of "
 				"this error, the AML code does not conform to "
 				"the ACPI specification and should be fixed.",
@@ -1304,37 +1437,60 @@ static void method_test_CRS_mif_maf(
 			fwts_advice(fw, "%s", mif_maf_advice);
 			*passed = false;
 		}
-		if ((mif == 1) && (min % (granularity + 1) != 0)) {
-			snprintf(tmp, sizeof(tmp), "Method%s%sMinNotMultipleOfGran", objname, tag);
-			if (fw->flags & FWTS_FLAG_TEST_SBBR)
+
+		if (mif == 1) {
+			const uint64_t tmpgran = granularity + 1;
+
+			if (tmpgran == 0) {
+				/* Avoid min % tmp division by zero, flag an error */
+				snprintf(tmp, sizeof(tmp), "Method%s%sGranTooLarge", objname, tag);
 				fwts_warning(fw, tmp,
-					"%s %s _MIN address is not a multiple "
-					"of the granularity when _MIF is 1.",
-					name, type);
-			else
-				fwts_failed(fw, LOG_LEVEL_MEDIUM,
-					tmp,
-					"%s %s _MIN address is not a multiple "
-					"of the granularity when _MIF is 1.",
-					name, type);
-			fwts_advice(fw, "%s", mif_maf_advice);
-			*passed = false;
+					"%s %s granularity 0x%" PRIx64 " is too large when _MIF is 1.",
+					name, type, granularity);
+				*passed = false;
+			} else if (min % tmpgran != 0) {
+				snprintf(tmp, sizeof(tmp), "Method%s%sMinNotMultipleOfGran", objname, tag);
+				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+					fwts_warning(fw, tmp,
+						"%s %s _MIN address is not a multiple "
+						"of the granularity when _MIF is 1.",
+						name, type);
+				else
+					fwts_failed(fw, LOG_LEVEL_MEDIUM,
+						tmp,
+						"%s %s _MIN address is not a multiple "
+						"of the granularity when _MIF is 1.",
+						name, type);
+				fwts_advice(fw, "%s", mif_maf_advice);
+				*passed = false;
+			}
 		}
-		if ((maf == 1) && (max % (granularity - 1) != 0)) {
-			snprintf(tmp, sizeof(tmp), "Method%s%sMaxNotMultipleOfGran", objname, tag);
-			if (fw->flags & FWTS_FLAG_TEST_SBBR)
+		if (maf == 1) {
+			const uint64_t tmpgran = granularity - 1;
+
+			if (tmpgran == 0) {
+				/* Avoid max % tmp division by zero, flag an error */
+				snprintf(tmp, sizeof(tmp), "Method%s%sGranTooSmall", objname, tag);
 				fwts_warning(fw, tmp,
-					"%s %s _MAX address is not a multiple "
-					"of the granularity when _MAF is 1.",
-					name, type);
-			else
-				fwts_failed(fw, LOG_LEVEL_MEDIUM,
-					tmp,
-					"%s %s _MAX address is not a multiple "
-					"of the granularity when _MAF is 1.",
-					name, type);
-			fwts_advice(fw, "%s", mif_maf_advice);
-			*passed = false;
+					"%s %s granularity 0x%" PRIx64 " is too small when _MAF is 1.",
+					name, type, granularity);
+				*passed = false;
+			} else if (max % tmpgran != 0) {
+				snprintf(tmp, sizeof(tmp), "Method%s%sMaxNotMultipleOfGran", objname, tag);
+				if (fw->flags & FWTS_FLAG_TEST_SBBR)
+					fwts_warning(fw, tmp,
+						"%s %s _MAX address is not a multiple "
+						"of the granularity when _MAF is 1.",
+						name, type);
+				else
+					fwts_failed(fw, LOG_LEVEL_MEDIUM,
+						tmp,
+						"%s %s _MAX address is not a multiple "
+						"of the granularity when _MAF is 1.",
+						name, type);
+				fwts_advice(fw, "%s", mif_maf_advice);
+				*passed = false;
+			}
 		}
 	} else {
 		if ((mif == 0) && (maf == 0) &&
@@ -1854,31 +2010,11 @@ int fwts_method_test_CID(fwts_framework *fw, ACPI_HANDLE *device)
 		"_CID", NULL, 0, fwts_method_test_CID_return, NULL);
 }
 
-void fwts_method_test_CLS_return(
-	fwts_framework *fw,
-	char *name,
-	ACPI_BUFFER *buf,
-	ACPI_OBJECT *obj,
-	void *private)
-{
-	FWTS_UNUSED(private);
-
-	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
-		return;
-
-	if (fwts_method_package_count_equal(fw, name, "_CLS", obj, 3) != FWTS_OK)
-		return;
-
-	if (fwts_method_package_elements_all_type(fw, name, "_CLS", obj, ACPI_TYPE_INTEGER) != FWTS_OK)
-		return;
-
-	fwts_method_passed_sane(fw, name, "package");
-}
-
 int fwts_method_test_CLS(fwts_framework *fw, ACPI_HANDLE *device)
 {
+	uint32_t element_size = 3;
 	return fwts_evaluate_method(fw, METHOD_OPTIONAL, device,
-		"_CLS", NULL, 0, fwts_method_test_CLS_return, NULL);
+		"_CLS", NULL, 0, fwts_method_test_package_integer_return, &element_size);
 }
 
 int fwts_method_test_DDN(fwts_framework *fw, ACPI_HANDLE *device)
@@ -2055,7 +2191,7 @@ void fwts_method_test_SUB_return(
 	FWTS_UNUSED(private);
 
 	if (obj == NULL) {
-		fwts_method_failed_null_object(fw, name, "a buffer or integer");
+		fwts_method_failed_null_object(fw, name, "a buffer");
 		return;
 	}
 
@@ -2080,7 +2216,7 @@ void fwts_method_test_SUB_return(
 		}
 	else {
 		fwts_failed(fw, LOG_LEVEL_MEDIUM, "Method_SUBBadReturnType",
-			"Method _SUB did not return a string or an integer.");
+			"Method _SUB did not return a string.");
 	}
 }
 
@@ -2144,4 +2280,34 @@ int fwts_method_test_UID(fwts_framework *fw, ACPI_HANDLE *device)
 		"_UID", NULL, 0, fwts_method_test_UID_return, NULL);
 }
 
+void fwts_method_test_BMD_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool failed = false;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_count_equal(fw, name, "_BMD", obj, 5) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_all_type(fw, name, "_BMD", obj, ACPI_TYPE_INTEGER) != FWTS_OK)
+		return;
+
+	fwts_acpi_reserved_bits_check(fw, "_BMD", "Status Flags",
+		obj->Package.Elements[0].Integer.Value, sizeof(uint32_t), 5, 31, &failed);
+
+	fwts_acpi_reserved_bits_check(fw, "_BMD", "Capability Flags",
+		obj->Package.Elements[1].Integer.Value, sizeof(uint32_t), 5, 31, &failed);
+
+	if (!failed)
+		fwts_method_passed_sane(fw, name, "package");
+}
+
 #endif
