@@ -1214,12 +1214,22 @@ int fwts_acpi_load_tables(fwts_framework *fw)
 		ret = fwts_acpi_load_tables_from_acpidump(fw);
 		require_fixup = true;
 	} else if (fwts_check_root_euid(fw, true) == FWTS_OK) {
-		ret = fwts_acpi_load_tables_from_firmware(fw);
+		if (!(fw->flags & FWTS_FLAG_DUMP_ACPI_FROM_SYSFS)) {
+			ret = fwts_acpi_load_tables_from_firmware(fw);
 
-		/* Load from memory failed (e.g. no /dev/mem), so try sysfs */
-		if (ret != FWTS_OK) {
+			/* Load from memory failed (e.g. no /dev/mem), so try sysfs */
+			if (ret != FWTS_OK) {
+				ret = fwts_acpi_load_tables_from_sysfs(fw);
+				require_fixup = true;
+			}
+		} else {
+			/* Load from sysfs */
 			ret = fwts_acpi_load_tables_from_sysfs(fw);
-			require_fixup = true;
+			if (ret != FWTS_OK) {
+				/* Load from sysfs failed, try from mem(e.g. /dev/mem) */
+				ret = fwts_acpi_load_tables_from_firmware(fw);
+			} else
+				require_fixup = true;
 		}
 	} else {
 		ret = FWTS_ERROR_NO_PRIV;
@@ -1618,7 +1628,7 @@ uint32_t fwts_get_acpi_version(fwts_framework *fw)
 	}
 
 	fadt = (fwts_acpi_table_fadt *) table->data;
-	acpi_version = (fadt->header.revision << 8) + fadt->minor_version;
+	acpi_version = (fadt->header.revision << 8) + (fadt->minor_version << 4);
 
 	/* check FACP returns an invalid value */
 	if (acpi_version > FWTS_ACPI_VERSION_NEXT ||
