@@ -25,6 +25,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
+#include <bsd/string.h>
 #include <limits.h>
 #include <dirent.h>
 #include <inttypes.h>
@@ -36,6 +37,20 @@ static inline bool fwts_battery_match(
 	return (((fwts_battery_type)index == FWTS_BATTERY_ALL) | (index == loop_index));
 }
 
+static inline void fwts_battery_path(
+	char *path,
+	const size_t path_len,
+	const char *battery_dir,
+	const char *name,
+	const char *str)
+{
+	(void)strlcpy(path, battery_dir, path_len);
+	(void)strlcat(path, "/", path_len);
+	(void)strlcat(path, name, path_len);
+	(void)strlcat(path, "/", path_len);
+	(void)strlcat(path, str, path_len);
+}
+
 static int fwts_battery_get_capacity_sys_fs(fwts_framework *fw,
 	DIR 	*dir,
 	const fwts_battery_type type,
@@ -77,7 +92,7 @@ static int fwts_battery_get_capacity_sys_fs(fwts_framework *fw,
 			bool match;
 
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				bool mismatch = (strstr(data, "Battery") == NULL);
 				free(data);
@@ -156,7 +171,8 @@ static int fwts_battery_get_capacity_proc_fs(fwts_framework *fw,
 			if (!match)
 				continue;
 
-			snprintf(path, sizeof(path), "%s/%s/%s", FWTS_PROC_ACPI_BATTERY, entry->d_name, file);
+			fwts_battery_path(path, sizeof(path), FWTS_PROC_ACPI_BATTERY, entry->d_name, file);
+
 			if ((fp = fopen(path, "r")) == NULL) {
 				fwts_log_info(fw, "Battery %s present but undersupported - no state present.", entry->d_name);
 			} else {
@@ -196,7 +212,7 @@ static int fwts_battery_get_count_sys_fs(DIR *dir, uint32_t *count)
 		entry = readdir(dir);
 		if (entry && strlen(entry->d_name) > 2) {
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				if (strstr(data, "Battery") != NULL)
 					(*count)++;
@@ -221,7 +237,8 @@ static int fwts_battery_get_count_proc_fs(DIR *dir, uint32_t *count)
 static int fwts_battery_get_name_sys_fs(
 	DIR *dir,
 	const uint32_t index,
-	char *name)
+	char *name,
+	const size_t name_len)
 {
 	struct dirent *entry;
 	char path[PATH_MAX];
@@ -233,7 +250,7 @@ static int fwts_battery_get_name_sys_fs(
 		if (entry && strlen(entry->d_name) > 2) {
 			bool match;
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				bool mismatch = (strstr(data, "Battery") == NULL);
 				free(data);
@@ -247,7 +264,7 @@ static int fwts_battery_get_name_sys_fs(
 			if (!match)
 				continue;
 
-			strcpy(name, entry->d_name);
+			strlcpy(name, entry->d_name, name_len);
 			return FWTS_OK;
 		}
 	} while (entry);
@@ -258,7 +275,8 @@ static int fwts_battery_get_name_sys_fs(
 static int fwts_battery_get_name_proc_fs(
 	DIR *dir,
 	const uint32_t index,
-	char *name)
+	char *name,
+	const size_t name_len)
 {
 	struct dirent *entry;
 	uint32_t i = 0;
@@ -271,7 +289,7 @@ static int fwts_battery_get_name_proc_fs(
 			if (!match)
 				continue;
 
-			strcpy(name, entry->d_name);
+			strlcpy(name, entry->d_name, name_len);
 			return FWTS_OK;
 		}
 	} while (entry);
@@ -304,7 +322,7 @@ static int fwts_battery_get_cycle_count_sys_fs(
 			bool match;
 
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				bool mismatch = (strstr(data, "Battery") == NULL);
 				free(data);
@@ -364,7 +382,8 @@ static int fwts_battery_get_cycle_count_proc_fs(
 			if (!match)
 				continue;
 
-			snprintf(path, sizeof(path), "%s/%s/%s", FWTS_PROC_ACPI_BATTERY, entry->d_name, file);
+			fwts_battery_path(path, sizeof(path), FWTS_PROC_ACPI_BATTERY, entry->d_name, file);
+
 			if ((fp = fopen(path, "r")) == NULL) {
 				fwts_log_info(fw, "Battery %s present but undersupported - no state present.", entry->d_name);
 			} else {
@@ -402,7 +421,7 @@ static int fwts_battery_set_trip_point_sys_fs(
 			bool match;
 
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				bool mismatch = (strstr(data, "Battery") == NULL);
 				free(data);
@@ -450,7 +469,7 @@ static int fwts_battery_get_trip_point_sys_fs(
 			bool match;
 
 			/* Check that type field matches the expected type */
-			snprintf(path, sizeof(path), "%s/%s/type", FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_SYS_CLASS_POWER_SUPPLY, entry->d_name, "type");
 			if ((data = fwts_get(path)) != NULL) {
 				bool mismatch = (strstr(data, "Battery") == NULL);
 				free(data);
@@ -500,7 +519,7 @@ static int fwts_battery_set_trip_point_proc_fs(
 			if (!match)
 				continue;
 
-			snprintf(path, sizeof(path), "%s/%s/alarm", FWTS_PROC_ACPI_BATTERY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_PROC_ACPI_BATTERY, entry->d_name, "alarm");
 			if ((fp = fopen(path, "rw+")) == NULL) {
 				fwts_log_info(fw, "Battery %s present but undersupported - no state present.", entry->d_name);
 			} else {
@@ -537,7 +556,7 @@ static int fwts_battery_get_trip_point_proc_fs(
 			if (!match)
 				continue;
 
-			snprintf(path, sizeof(path), "%s/%s/alarm", FWTS_PROC_ACPI_BATTERY, entry->d_name);
+			fwts_battery_path(path, sizeof(path), FWTS_PROC_ACPI_BATTERY, entry->d_name, "alarm");
 			if ((fp = fopen(path, "r")) == NULL) {
 				fwts_log_info(fw, "Battery %s present but undersupported - no state present.", entry->d_name);
 			} else {
@@ -639,18 +658,21 @@ int fwts_battery_get_cycle_count(
 int fwts_battery_get_name(
 	fwts_framework *fw,
 	const uint32_t index,
-	char *name)
+	char *name,
+	const size_t name_len)
 {
 	int ret;
 	DIR *dir;
 
 	FWTS_UNUSED(fw);
 
+	(void)memset(name, 0, name_len);
+
 	if ((dir = opendir(FWTS_SYS_CLASS_POWER_SUPPLY)) != NULL) {
-		ret = fwts_battery_get_name_sys_fs(dir, index, name);
+		ret = fwts_battery_get_name_sys_fs(dir, index, name, name_len);
 		(void)closedir(dir);
 	} else if ((dir = opendir(FWTS_PROC_ACPI_BATTERY)) != NULL) {
-		ret = fwts_battery_get_name_proc_fs(dir, index, name);
+		ret = fwts_battery_get_name_proc_fs(dir, index, name, name_len);
 		(void)closedir(dir);
 	} else {
 		return FWTS_ERROR;
