@@ -139,6 +139,7 @@ static fwts_option fwts_framework_options[] = {
 	{ "ifv",		"",   0, "Run tests in firmware-vendor modes." },
 	{ "clog",		"",   1, "Specify a coreboot logfile dump" },
 	{ "ebbr",		"",   0, "Run ARM EBBR tests." },
+	{ "dump-acpi-from-sysfs","",  0, "Specify dumping acpi table log default from sysfs." },
 	{ NULL, NULL, 0, NULL }
 };
 
@@ -1157,8 +1158,10 @@ static int fwts_framework_an_parse(fwts_framework *fw, const char *arg)
 {
 	fw->target_arch = fwts_arch_get_arch(arg);
 	if (fw->target_arch == FWTS_ARCH_OTHER) {
-		fprintf(stderr, "--arch can be one of: %s\n",
-			fwts_arch_names());
+		char *names = fwts_arch_names();
+
+		fprintf(stderr, "--arch can be one of: %s\n", names ? names : "<unknown>");
+		free(names);
 		return FWTS_ERROR;
 	}
 
@@ -1345,6 +1348,9 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 		case 49: /* --ebbr */
 			fw->flags |= FWTS_FLAG_TEST_EBBR;
 			break;
+		case 50: /* --dump-acpi-from-sysfs */
+			fw->flags |= FWTS_FLAG_DUMP_ACPI_FROM_SYSFS;
+			break;
 		}
 		break;
 	case 'a': /* --all */
