@@ -95,25 +95,8 @@ static void uefirtvariable_env_cleanup(void)
 
 static int uefirtvariable_init(fwts_framework *fw)
 {
-	if (fwts_firmware_detect() != FWTS_FIRMWARE_UEFI) {
-		fwts_log_info(fw, "Cannot detect any UEFI firmware. Aborted.");
+	if (fwts_lib_efi_runtime_module_init(fw, &fd) == FWTS_ABORTED)
 		return FWTS_ABORTED;
-	}
-
-	if (fwts_lib_efi_runtime_kernel_lockdown(fw) == FWTS_ABORTED) {
-		return FWTS_ABORTED;
-	}
-
-	if (fwts_lib_efi_runtime_load_module(fw) != FWTS_OK) {
-		fwts_log_info(fw, "Cannot load efi_runtime module. Aborted.");
-		return FWTS_ABORTED;
-	}
-
-	fd = fwts_lib_efi_runtime_open();
-	if (fd == -1) {
-		fwts_log_info(fw, "Cannot open EFI test driver. Aborted.");
-		return FWTS_ABORTED;
-	}
 
 	uefirtvariable_env_cleanup();
 
@@ -466,12 +449,11 @@ err_restore_env:
 	status = ~0ULL;
 
 	ioret = ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
-
 	if (ioret == -1) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
 			"Failed to delete variable with UEFI runtime service.");
 		fwts_uefi_print_status_info(fw, status);
-		return FWTS_ERROR;
+		ret = FWTS_ERROR;
 	}
 
 	if (variablename)
